None.Serial

Class Serial |
[show private | hide private]
[frames | no frames]

## Type Serial

    object --+
             |
            Serial

Known Subclasses:
  `SpoonRPCHello`

Method Summary
| `__new__(cls, *args, **kwargs)` (Static method)
| ``decode_lazy`(self)` Decode all of the attributes marked as lazy that have not yet been decoded.
| ``post_deserialize`(self)` Called after an object is received over the network, instead of the normal `__init__` method.
| ``pre_serialize`(self)` Called right before this object's attributes are encoded into a stream for network travel.
Inherited from object
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`type` | `__metaclass__` = `None.SerialMeta`

Instance Method Details

### decode_lazy(self) Decode all of the attributes marked as lazy that have not yet been decoded. Returns: Number of attributes decoded. Warning: Some sort of instance level locking should be done

### post_deserialize(self) Called after an object is received over the network, instead of the normal `__init__` method.

### pre_serialize(self) Called right before this object's attributes are encoded into a stream for network travel.

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net